@@ -3,8 +3,10 @@ import pytz
 from pytest import raises
 from collections import OrderedDict
 from datetime import datetime, date, time, timedelta
-from json_tricks.test_class import MyTestCls, CustomEncodeCls
-from json_tricks.nonp import strip_comments, dumps, loads, DuplicateJsonKeyException
+from .test_class import MyTestCls, CustomEncodeCls
+from .nonp import strip_comments, dumps, loads, DuplicateJsonKeyException
+from math import pi
+
 
 nonpdata = {
 	'my_array': list(range(20)),
@@ -122,3 +124,9 @@ def test_date_time():
 	assert obj == datetime(year=1988, month=3, day=15, hour=8, minute=3, second=59, microsecond=7, tzinfo=pytz.timezone('Europe/Amsterdam'))
 
 
+def test_float_precision():
+	json = dumps([pi])
+	back = loads(json)
+	assert back[0] - pi == 0, 'Precision lost while encoding and decoding float.'
+
+
